@@ -4,3 +4,6 @@ from .adds.parsing import parsing
 from .adds.add_lr import lr
 from .adds.annotation import annotation
 from .adds.add_labels import labels
+from .adds.auto_annotate import auto_annotate
+from .adds.add_mask import add_mask
+from .adds.add_mask import apply_mask
\ No newline at end of file
